use std::sync::Arc;

use crate::model::Model;
use crate::server::AppContext;

pub fn get_model(ctx: Arc<AppContext>, name: String) -> Option<Model> {
    ctx.project
        .models
        .clone()
        .into_iter()
        .find(|m| m.name == name)
}
